pocketpose.converters.torch2tflite - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.converters.torch2tflite`

## Module Contents

### Classes

`Torch2TFLiteConverter` | Helper class that provides a standard way to create an ABC using

class pocketpose.converters.torch2tflite.Torch2TFLiteConverter(overwrite=True, log_level=logging.INFO, onnx_opset_version=17, use_tf_ops=False, quantize=TF2TFLiteConverter.QUANTIZE_NONE)

  Bases: `pocketpose.converters.base_converter.BaseConverter`

  Helper class that provides a standard way to create an ABC using inheritance.

  _convert(model, save_path, *args, **kwargs)

    Convert the model to the target format and save it to the given path.

    Args:

      model (Any): The model to convert. save_path (str): Where to save the converted model. *args: Variable length argument list for the model. **kwargs: Arbitrary keyword arguments for the model.

    Returns:

      Any: The converted model.

    Raises:

      NotImplementedError: If the subclass does not implement this method.